@@ -8,10 +8,8 @@ import requests
 #from models.html_form import Html_form
 
 # These lines ensure fiels are retrievable once packaged as a library
-import sys, os
-sys.path.append('kraken_html/content_template')
-sys.path.append('kraken_html/html_template')
 
+CONTENT_TEMPLATE = 'content_template/'
 
 class Kraken_html:
     """ Class to generate html pages based on standard kraken records
@@ -261,7 +259,7 @@ class Kraken_html:
 
     def get_record_template(self, page, language = 'en'):
         # Get file Name. 
-        filename = 'kraken_html/content_template/' + page + '_' + language + '.json'
+        filename = CONTENT_TEMPLATE + page + '_' + language + '.json'
 
         # Load file
         f = open(filename, "r")
